
#ifndef GUARD_nconv_h
#define GUARD_nconv_h

#include "common.h"

#define NCONV_SIGN 0x80
#define NCONV_FILLSPACE (1)
#define NCONV_FILLZERO (2)

#define nconv_init()

/* Converts n, an IEEE-754 format 32-bit number, into a
string.  The string is stored in s.  Total number of digits to
use is given in dig, and may be a maximum of 16.  Total number of
decimal places is in dp, and may be a maximum of 16.

Exponential notation is not used.  The conversion itself uses a 32-bit
accumulator, and the assumed '1' bit is included in this.  Since the
routine outputs only decimal notation, it has a limited conversion
range.  Numbers whose exponent is greater than 33 are represented by
"-LG" or "+LG", depending on the sign; numbers whose exponent is less
than -32 are represented by "-SM" or "+SM".

Numbers with an exponent less than -8 lose some precision during
conversion, since mantissa bits get shifted out.

mode is:

high bit set - print neg and pos signs always
high bit clear - print neg sign only, no pos
bits 0-1 - used for decimal part

*/
int f2asc(float n, int idigs, int fdigs, char mode, char *s);

/* Converts fixed-point binary number n to an ASCII string.

The string is stored in s.  bp (binary point) is in the range [0,32].

The conversion is performed using BCD arithmetic.  The number is first
separated into integer and fractional components, and each of these
are converted separately.
*/
int fixed2asc(u32 n, int bp, int idigs, int fdigs, int mode, char *s);

/* Converts a binary number N into a hexadecimal ASCII string.

Up to digs digits are converted under the control of mode, as follows:

- mode = 0: Leading zeroes are not printed.  The string may be
  less than digs digits long.
- mode = 1: Spaces are printed in place of leading zeroes.  The
  string will be digs digits long.
- mode = 2: Leading zeroes are printed.  The string will be digs
  digits long.

If the number is zero, at least one zero is printed in all modes.

Note that this routine can also be used with 4-bit packed BCD
numbers.

Because n is passed as a void pointer, the converted number may be
arbitrarily long.

\note Currently the routine has big-endian code activated by the
LITTLEENDIAN macro.  The big-endian code assumes 64 bit BCD input.
This will be fixed in future.  The macro will also be changed to a
standard macro, if I can find one.

*/
int hex2asc(void *n, int digs, int mode, char *s);

/* Converts a 32-bit integer n into an ASCII string.

digs is the maximum number of digits to display.  Conversion is controlled 
by mode, as follows:

- mode = 0: Leading zeroes are not printed.  The string may be
  less than digs digits long.
- mode = 1: Spaces are printed in place of leading zeroes.  The
  string will be digs digits long.
- mode = 2: Leading zeroes are printed.  The string will be digs
  digits long.

If the number is zero, at least one zero is printed in all modes.

This routine works by converting n to an 8-byte BCD number and calling 
hex2asc.  No division by 10 is performed.
*/
int int2asc(u32 n, int digs, int mode, char *s);

/* Adds two 64-bit BCD numbers pointed to by a and b to carry c, and 
stores the result in a.  This routine is used by int2asc for BCD
conversion. */
/* Written in assembly for speed; code is in bcd.s */
short bcd64add(unsigned long long *a, unsigned long long *b, short c);

/* Divides the 64-bit BCD number a by 2.  This routine is used by int2asc 
for BCD conversion. */
/* Written in assembly for speed; code is in bcd.s */
void bcd64div2(unsigned long long *a);

void bcd2tochars(char n, char *s);
void bcd16tostr(u64 *n, char *c);
void frac2asc(u32 n, int digs, char *s);


#endif
